%define upstream_name phonon-backend-vlc

%bcond_without qt5
%bcond_without qt6

%define rel 2

Name:           phonon-vlc
Version:        0.12.0
Release:        %mkrel %{rel}
Summary:        VLC backend for Phonon
License:        LGPLv2
Group:          Video/Utilities
URL:            https://invent.kde.org/libraries/phonon-vlc
Source0:        https://download.kde.org/stable/phonon/%{upstream_name}/%{version}/%{upstream_name}-%{version}.tar.xz

BuildRequires:  cmake
BuildRequires:  cmake(ECM)
BuildRequires:  pkgconfig(libvlc) >= 2.0.1

### Qt5 build dependencies
%if %{with qt5}
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Help)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(phonon4qt5)
%endif
### Qt6 build dependencies
%if %{with qt6}
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(phonon4qt6)
%endif

%description
This package allows Phonon (the KDE media library) to use VLC
for audio and video playback.

#--------------------------------------------------------------------

%package        i18n
Summary:        Translation files for %{name}
Group:          System/Libraries
BuildArch:      noarch

%description    i18n
This package contains translation files for %{name}.

%files i18n -f phonon_vlc.lang

#--------------------------------------------------------------------

%if %{with qt5}
%package -n phonon4qt5-vlc
Summary:        VLC backend for Phonon Qt5
Group:          Video/Utilities

Provides:       phonon4qt5-backend
Provides:       phonon4qt5-backend-vlc

Requires:       %{name}-i18n >= %{version}-%{release}
Requires:       vlc-plugin-common
Recommends:     vlc-plugin-pulse

%description -n phonon4qt5-vlc
This package allows Phonon Qt5 (the KDE media library) to use VLC
for audio and video playback.

%files -n phonon4qt5-vlc
%doc AUTHORS
%license COPYING.LIB
%{_qt5_plugindir}/phonon4qt5_backend/phonon_vlc_qt5.so
%endif

#--------------------------------------------------------------------

%if %{with qt6}
%package -n phonon4qt6-vlc
Summary:        VLC backend for Phonon Qt6
Group:          Video/Utilities

Provides:       phonon4qt6-backend
Provides:       phonon4qt6-backend-vlc

Requires:       %{name}-i18n >= %{version}-%{release}
Requires:       vlc-plugin-common
Recommends:     vlc-plugin-pulse

%description -n phonon4qt6-vlc
This package allows Phonon Qt6 (the KDE media library) to use VLC
for audio and video playback.

%files -n phonon4qt6-vlc
%doc AUTHORS
%license COPYING.LIB
%{_qt6_plugindir}/phonon4qt6_backend/phonon_vlc_qt6.so
%endif

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n %{upstream_name}-%{version}

%build
### Qt5 Build ###
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_qt5 -DPHONON_BUILD_QT6:BOOL=OFF
%cmake_build
%endif

### Qt6 Build ###
%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_qt6 -DPHONON_BUILD_QT5:BOOL=OFF
%cmake_build
%endif

%install
### Qt5 Install ###
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_install
%endif

### Qt6 Install ###
%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_install
%endif

%find_lang phonon_vlc --with-qt


%changelog
* Sat Jun 28 2025 umeabot <umeabot> 0.12.0-2.mga10
+ Revision: 2220262
- Mageia 10 Mass Rebuild

* Sun Nov 05 2023 daviddavid <daviddavid> 0.12.0-1.mga10
+ Revision: 2004264
- new version: 0.12.0
- add Qt6 support
- split out in a separate sub-pkg all translations files in
  order to avoid conflicts between Qt5 and Qt6

* Mon Apr 04 2022 umeabot <umeabot> 0.11.3-2.mga9
+ Revision: 1843737
- Mageia 9 Mass Rebuild

* Sun Aug 08 2021 luigiwalser <luigiwalser> 0.11.3-1.mga9
+ Revision: 1740269
- 0.11.3

* Thu Dec 17 2020 umeabot <umeabot> 0.11.1-2.mga8
+ Revision: 1659378
- Rebuild for new Qt5

* Mon Mar 02 2020 daviddavid <daviddavid> 0.11.1-1.mga8
+ Revision: 1552919
- new version: 0.11.1
- qt4 support removed upstream (can be packaged separately as phonon-qt4-vlc if needed)

* Sat Feb 15 2020 umeabot <umeabot> 0.10.2-3.mga8
+ Revision: 1524853
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon Apr 01 2019 umeabot <umeabot> 0.10.2-2.mga7
+ Revision: 1383905
- Qt5 Rebuild

* Mon Jan 14 2019 luigiwalser <luigiwalser> 0.10.2-1.mga7
+ Revision: 1356267
- 0.10.2

* Sat Dec 29 2018 luigiwalser <luigiwalser> 0.10.1-1.mga7
+ Revision: 1346517
- 0.10.1

* Sun Sep 23 2018 umeabot <umeabot> 0.10.0-2.mga7
+ Revision: 1300205
- Mageia 7 Mass Rebuild

* Sat Feb 24 2018 daviddavid <daviddavid> 0.10.0-1.mga7
+ Revision: 1204738
- new version: 0.10.0

* Mon Jan 01 2018 ghibo <ghibo> 0.9.1-6.mga7
+ Revision: 1188859
- Rebuilt against libvlccore9

* Sat Dec 30 2017 kekepower <kekepower> 0.9.1-5.mga7
+ Revision: 1187695
- Rebuild for mga7

* Sun Feb 26 2017 neoclust <neoclust> 0.9.1-4.mga6
+ Revision: 1087916
- New version 0.9.1 ( add support for newer vlc )

* Sat Feb 11 2017 daviddavid <daviddavid> 0.9.0-4.mga6
+ Revision: 1085696
- backport upstream fixes to make it build with libvlc >= 3.0.0

* Wed May 11 2016 neoclust <neoclust> 0.9.0-3.mga6
+ Revision: 1013652
- New version 0.9.0

* Tue Feb 09 2016 umeabot <umeabot> 0.8.2-3.mga6
+ Revision: 952364
- Mageia 6 Mass Rebuild

* Wed Feb 18 2015 luigiwalser <luigiwalser> 0.8.2-2.mga5
+ Revision: 815703
- add upstream patches for better compatibility with vlc 2.2
- rebuild for VLC 2.2.0 and libvlccore8

* Sat Feb 07 2015 luigiwalser <luigiwalser> 0.8.2-1.mga5
+ Revision: 813991
- 0.8.2

* Wed Dec 03 2014 lmenut <lmenut> 0.8.1-1.mga5
+ Revision: 800528
- Update to 0.8.1
- obsoletes phonon-xine
- update default backend
  phonon-gstreamer -> phonon-vlc

* Wed Oct 15 2014 umeabot <umeabot> 0.8.0-3.mga5
+ Revision: 742190
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.8.0-2.mga5
+ Revision: 687084
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sun Sep 07 2014 lmenut <lmenut> 0.8.0-1.mga5
+ Revision: 673236
- update to 0.8.0
- build phonon4qt5 backend

* Sat Jul 12 2014 lmenut <lmenut> 0.7.2-1.mga5
+ Revision: 651541
- update to 0.7.2

* Tue Feb 18 2014 neoclust <neoclust> 0.7.1-1.mga5
+ Revision: 594170
- New version

* Mon Oct 21 2013 umeabot <umeabot> 0.6.2-2.mga4
+ Revision: 537291
- Mageia 4 Mass Rebuild

* Wed Feb 13 2013 neoclust <neoclust> 0.6.2-1.mga4
+ Revision: 398285
- New version

* Sun Jan 13 2013 umeabot <umeabot> 0.6.1-2.mga3
+ Revision: 375652
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 16 2012 mikala <mikala> 0.6.1-1.mga3
+ Revision: 319004
- Use Video/Utilities for Group
- Update tarball to 0.6.1

* Fri Sep 07 2012 fwang <fwang> 0.6.0-1.mga3
+ Revision: 289139
- new version 0.6.0

* Tue Feb 28 2012 colin <colin> 0.5.0-1.mga2
+ Revision: 215888
- New version: 0.5.0
- Backport patches from git master to compile against new phonon
+ mikala <mikala>
- Switch to pkgconfig() buildrequires
- remove %%defattr
- use kde layout and macro
- fix license
- update url
- Update tarball to 0.4.1

* Tue Apr 26 2011 mikala <mikala> 0.4.0-1.mga1
+ Revision: 91857
- Update to 0.4.0

* Tue Mar 08 2011 mikala <mikala> 0.3.2-4.mga1
+ Revision: 66598
- Add vlc-plugin-vlc as a suggest

* Fri Feb 18 2011 mikala <mikala> 0.3.2-3.mga1
+ Revision: 53837
- Add vlc-plugin-common as Require
- Drop BuildRoot

* Wed Jan 26 2011 ahmad <ahmad> 0.3.2-2.mga1
+ Revision: 41207
- use current phonon Epoch in the phonon-devel BR
- imported package phonon-vlc


* Sat Jan 22 2011 Funda Wang <fwang@mandriva.org> 0.3.2-1mdv2011.0
+ Revision: 632261
- New version 0.3.2

* Sat Dec 04 2010 Funda Wang <fwang@mandriva.org> 0.3.1-1mdv2011.0
+ Revision: 608593
- new version 0.3.1

* Sun Jul 25 2010 Colin Guthrie <cguthrie@mandriva.org> 0.2.0-1mdv2011.0
+ Revision: 559112
- New version: 0.2.0
- Update to latest git master

* Sun Apr 04 2010 Colin Guthrie <cguthrie@mandriva.org> 0.0.0-0.20100404.1mdv2010.1
+ Revision: 531409
- New snapshot

* Thu Feb 11 2010 Colin Guthrie <cguthrie@mandriva.org> 0.0.0-0.20100211.1mdv2010.1
+ Revision: 504368
- import phonon-vlc


